#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

import libevh.evhcmd as evhcmd
from iobase.exception import InvalidArgError
from product_conf.reqinfo import ReqTypes
from libevh.util import set_manual, regist_man_set_event

EVENTINFO_NAME = "eventinfo"
CATEGORY_ATTR = "category"
ACTION_ATTR = "action"
PREVIOUS_ATTR = "previous"

VOLUME_CATEGORY = "volume"
MOUNT_ACTION = "mount"
MKFS_ACTION = "mkfs"

SELF_HANDLER = "/mnt/data/libexec/evh/evh_apple_manual_set.py"

MAN_NAME = "hdlh-appleshare-manual.pdf"


class EventHandler(evhcmd.EvhCmd):

    def __get_action_method(self, entry):

        category = \
            entry.get().get_node(EVENTINFO_NAME).get_attr_value(CATEGORY_ATTR)

        action = \
            entry.get().get_node(EVENTINFO_NAME).get_attr_value(ACTION_ATTR)

        is_previous = \
            entry.get().get_node(EVENTINFO_NAME).is_set_to_true(PREVIOUS_ATTR)

        if VOLUME_CATEGORY == category and MKFS_ACTION == action and \
           False == is_previous:
            return self.__regist_man_set_event

        if VOLUME_CATEGORY == category and MOUNT_ACTION == action and \
           False == is_previous:
            return self.__set_manual

        raise InvalidArgError

    def __regist_man_set_event(self, entry):

        return regist_man_set_event(entry, SELF_HANDLER)

    def __set_manual(self, entry):

        return set_manual(entry, [MAN_NAME], SELF_HANDLER)
    #
    # Request handlers
    #

    def __event_handler(self, entry):
        """Handle "event" request."""

        handle_method = self.__get_action_method(entry)
        return handle_method(entry)

    def __init__(self, option=None):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, option=option)

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EventHandler(option=evhcmd.EvhCmdOption()).handle_request()
